package com.idea.buyingMore.service;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.idea.buyingMore.mapper.BuyingMoreMapper;
import com.idea.buyingMore.model.BuyingMore;
import com.idea.buyingMore.model.BuyingMoreExample;
import com.idea.util.DateUtils;
import com.rockstar.common.base.BaseService;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.frame.model.extend.Tablepar;
import com.rockstar.shiro.util.ShiroUtils;
import com.rockstar.util.StringUtils;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class BuyingMoreService implements BaseService<BuyingMore, BuyingMoreExample> {

    private BuyingMoreMapper modelMapper;


    @Override
    public int deleteByPrimaryKey(String s) {
        return modelMapper.deleteByPrimaryKey(s);
    }

    @Override
    public int insertSelective(BuyingMore buyingMore) {
        buyingMore.setId(IdUtil.simpleUUID());
        return modelMapper.insertSelective(buyingMore);
    }

    public int insertWithoutId(BuyingMore buyingMore) {
        return modelMapper.insertSelective(buyingMore);
    }

    @Override
    public BuyingMore selectByPrimaryKey(String s) {
        return modelMapper.selectByPrimaryKey(s);
    }

    @Override
    public int updateByPrimaryKeySelective(BuyingMore buyingMore) {
        return modelMapper.updateByPrimaryKeySelective(buyingMore);
    }

    @Override
    public int updateByExampleSelective(BuyingMore buyingMore, BuyingMoreExample buyingMoreExample) {
        return modelMapper.updateByExampleSelective(buyingMore, buyingMoreExample);
    }

    @Override
    public int updateByExample(BuyingMore buyingMore, BuyingMoreExample buyingMoreExample) {
        return modelMapper.updateByExample(buyingMore, buyingMoreExample);
    }

    @Override
    public List<BuyingMore> selectByExample(BuyingMoreExample buyingMoreExample) {
        return modelMapper.selectByExample(buyingMoreExample);
    }

    @Override
    public long countByExample(BuyingMoreExample buyingMoreExample) {
        return modelMapper.countByExample(buyingMoreExample);
    }

    @Override
    public int deleteByExample(BuyingMoreExample buyingMoreExample) {
        return modelMapper.deleteByExample(buyingMoreExample);
    }

    /**
     * 新增
     *
     * @param model
     * @return
     */
    public int add(BuyingMore model) {

        String serialNumber = getSerialNumber(model.getType());
        model.setDelFlag(0);
        model.setSerialNumber(serialNumber);
        model.setCreatedId(ShiroUtils.getUserId());
        model.setCreatedAt(new Date());
        int result = modelMapper.insertSelective(model);
        return result;
    }

    /**
     * 编辑
     *
     * @param model
     * @return
     */
    public int edit(BuyingMore model) {
        model.setUpdatedId(ShiroUtils.getUserId());
        model.setUpdatedAt(new Date());
        int result = modelMapper.updateByPrimaryKeySelective(model);
        return result;
    }

    /**
     * 删除
     *
     * @param id
     * @return
     */
    public int delete(String id) {
        int result = 0;
        BuyingMore buyingMore = modelMapper.selectByPrimaryKey(id);
        if (ObjectUtil.isNotNull(buyingMore)) {
            buyingMore.setDelFlag(1);
            result = modelMapper.updateByPrimaryKeySelective(buyingMore);
        }
        return result;
    }

    public String getSerialNumber(Integer type) {

        BuyingMoreExample example = new BuyingMoreExample();
        example.createCriteria().andTypeEqualTo(type);
        Long count = countByExample(example);
        String number = "";
        if (count.doubleValue() == 0) {
            number = "0001";
        } else {
            count++;
            number = String.format("%04d", count);
        }
        String year = DateUtils.getYear(new Date(), 0);
        String serialNumber = "";
        if (type == 1) {
            serialNumber = "ZG-" + year + "-" + number;
        }
        if (type == 2) {
            serialNumber = "HG-" + year + "-" + number;
        }
        return serialNumber;
    }

    /**
     * 分页查询
     *
     * @return
     */
    public PageInfo<BuyingMore> list(Tablepar tablepar, BuyingMore model, DateTrans dt) {
        PageHelper.startPage(tablepar.getPageNum(), tablepar.getPageSize());
        List<BuyingMore> list = modelMapper.selectByExample(getCondition(model, dt));
        PageInfo<BuyingMore> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 查询指定
     *
     * @return
     */
    public List<BuyingMore> listAll(BuyingMore model, DateTrans dt) {
        return modelMapper.selectByExample(getCondition(model, dt));
    }

    private BuyingMoreExample getCondition(BuyingMore model, DateTrans dt) {
        BuyingMoreExample ex = new BuyingMoreExample();
        ex.setOrderByClause("order_num asc");
        BuyingMoreExample.Criteria criteria = ex.createCriteria();
        criteria.andDelFlagEqualTo(0);
        if (StringUtils.isNotEmpty(model.getBuyerName())) {
            criteria.andBuyerNameLike("%" + model.getBuyerName() + "%");
        }
        if (StringUtils.isNotEmpty(model.getHouseName())) {
            criteria.andHouseNameLike("%" + model.getHouseName() + "%");
        }
        return ex;
    }


}
